## Project Description

With *django-routine*, you can create a basic django project with a single command!

## Requirements

* Python (3.9 or higher)

## Installation
Install using pip

`pip install django-routine`

## P.S.

If you find bugs, need help, or want to talk to the developers, please write an issue on [GitHub](https://github.com/DCDie/azure-transcribe/issues).
